@@ -1,14 +1,12 @@
-use crate::{
-    config,
-    config::structs::{Mod, ModIdentifier},
-};
+use crate::config::structs::{Mod, ModIdentifier, Profile};
 use ferinth::{
     structures::project_structs::{Project, ProjectType},
     Ferinth,
 };
 use furse::Furse;
-use octocrab::{models::Repository, repos::RepoHandler};
+use octorust::{repos::Repos, types::FullRepository};
 use reqwest::StatusCode;
+use std::sync::Arc;
 
 type Result<T> = std::result::Result<T, Error>;
 #[derive(thiserror::Error, Debug)]
@@ -19,8 +17,8 @@ pub enum Error {
     DoesNotExist,
     #[error("The project/repository is not a mod")]
     NotAMod,
-    #[error("{}", .0)]
-    GitHubError(octocrab::Error),
+    #[error("GitHub: {}", .0)]
+    GitHubError(#[from] anyhow::Error),
     #[error("{}", .0)]
     ModrinthError(ferinth::Error),
     #[error("{}", .0)]
@@ -55,51 +53,36 @@ impl From<ferinth::Error> for Error {
     }
 }
 
-impl From<octocrab::Error> for Error {
-    fn from(err: octocrab::Error) -> Self {
-        if let octocrab::Error::Http { source, .. } = &err {
-            if Some(StatusCode::NOT_FOUND) == source.status() {
-                Self::DoesNotExist
-            } else {
-                Self::GitHubError(err)
-            }
-        } else {
-            Self::GitHubError(err)
-        }
-    }
-}
-
-/// Check if repo of `repo_handler` exists and releases mods, and if so add the repo to `profile`
+/// Check if the repo of `repo_handler` exists and releases mods, and if so add the repo to `profile`
 pub async fn github(
-    repo_handler: &RepoHandler<'_>,
-    profile: &mut config::structs::Profile,
+    github: Repos,
+    repo_name: (&str, &str),
+    profile: &mut Profile,
     should_check_game_version: Option<bool>,
     should_check_mod_loader: Option<bool>,
-) -> Result<Repository> {
-    let repo = repo_handler.get().await?;
+) -> Result<FullRepository> {
+    let repo = github.get(repo_name.0, repo_name.1).await?;
     // Get the name of the repository as a tuple
-    let repo_name_split = repo
-        .full_name
-        .as_ref()
-        .unwrap()
-        .split('/')
-        .collect::<Vec<_>>();
+    let repo_name_split = repo.full_name.split('/').collect::<Vec<_>>();
     let repo_name = (repo_name_split[0].into(), repo_name_split[1].into());
 
+    // Check if project has already been added
     if profile.mods.iter().any(|mod_| {
-        config::structs::ModIdentifier::GitHubRepository(repo_name.clone()) == mod_.identifier
+        mod_.name == repo.name
+            || ModIdentifier::GitHubRepository(repo_name.clone()) == mod_.identifier
     }) {
         return Err(Error::AlreadyAdded);
     }
 
-    let releases = repo_handler.releases().list().send().await?;
+    let releases = github
+        .list_releases(&repo_name.0, &repo_name.1, 100, 0)
+        .await?;
     let mut contains_jar_asset = false;
 
-    // Search every asset to check if the releases contain JAR files (a mod file)
+    // Check if the releases contain a JAR file
     'outer: for release in releases {
         for asset in release.assets {
             if asset.name.contains("jar") {
-                // If JAR release is found, set flag to true and break
                 contains_jar_asset = true;
                 break 'outer;
             }
@@ -127,22 +110,21 @@ pub async fn github(
     }
 }
 
-/// Check if `project_id` exists and is a mod, if so add that project ID to `profile`
-/// Returns the project struct
+/// Check if the project of `project_id` exists and is a mod, if so add the project to `profile`
 pub async fn modrinth(
-    modrinth: &Ferinth,
+    modrinth: Arc<Ferinth>,
     project_id: &str,
-    profile: &mut config::structs::Profile,
+    profile: &mut Profile,
     should_check_game_version: Option<bool>,
     should_check_mod_loader: Option<bool>,
 ) -> Result<Project> {
     let project = modrinth.get_project(project_id).await?;
     // Check if project has already been added
     if profile.mods.iter().any(|mod_| {
-        config::structs::ModIdentifier::ModrinthProject(project.id.clone()) == mod_.identifier
+        mod_.name == project.title
+            || ModIdentifier::ModrinthProject(project.id.clone()) == mod_.identifier
     }) {
         Err(Error::AlreadyAdded)
-    // Check that the project is a mod
     } else if project.project_type != ProjectType::Mod {
         Err(Error::NotAMod)
     } else {
@@ -164,19 +146,18 @@ pub async fn modrinth(
     }
 }
 
-/// Check if `project_id` exists, if so add that mod to `profile`
-/// Returns the mod struct
+/// Check if the mod of `project_id` exists, if so add that mod to `profile`
 pub async fn curseforge(
-    curseforge: &Furse,
+    curseforge: Arc<Furse>,
     project_id: i32,
-    profile: &mut config::structs::Profile,
+    profile: &mut Profile,
     should_check_game_version: Option<bool>,
     should_check_mod_loader: Option<bool>,
 ) -> Result<furse::structures::mod_structs::Mod> {
     let project = curseforge.get_mod(project_id).await?;
     // Check if project has already been added
     if profile.mods.iter().any(|mod_| {
-        config::structs::ModIdentifier::CurseForgeProject(project.id) == mod_.identifier
+        mod_.name == project.name || ModIdentifier::CurseForgeProject(project.id) == mod_.identifier
     }) {
         Err(Error::AlreadyAdded)
     } else {
